@@ -2,7 +2,7 @@
 #------------------------------------------
 # Parse RCS archive file.
 #------------------------------------------
-use Version::Rcs;
+use Rcs;
 
 $obj = Rcs->new;
 
